==> _private_core_network-1.1.5.tar.gz: lib/network_resources/model/product_reference.dart <==

class ProductReference {
  int? id;
  int? planDuration;
  int? rentDuration;
  int? workDuration;
  int? numberOfItems;
  String? reference;
  String? description;
  String? pictureUrl;
  String? codeReference;
  int? categoryId;
  int? purchaseType;
  int? warrantyDuration;
  int? serialNumberFormatId;
  String? label;

  ProductReference({this.id, this.planDuration, this.rentDuration, this.workDuration, this.numberOfItems, this.reference, this.description, this.pictureUrl, this.codeReference, this.categoryId, this.purchaseType, this.warrantyDuration, this.serialNumberFormatId, this.label});

  ProductReference.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    planDuration = json["planDuration"];
    rentDuration = json["rentDuration"];
    workDuration = json["workDuration"];
    numberOfItems = json["numberOfItems"];
    reference = json["reference"];
    description = json["description"];
    pictureUrl = json["pictureUrl"];
    codeReference = json["codeReference"];
    categoryId = json["categoryId"];
    purchaseType = json["purchaseType"];
    warrantyDuration = json["warrantyDuration"];
    serialNumberFormatId = json["serialNumberFormatId"];
    label = json["label"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["planDuration"] = planDuration;
    _data["rentDuration"] = rentDuration;
    _data["workDuration"] = workDuration;
    _data["numberOfItems"] = numberOfItems;
    _data["reference"] = reference;
    _data["description"] = description;
    _data["pictureUrl"] = pictureUrl;
    _data["codeReference"] = codeReference;
    _data["categoryId"] = categoryId;
    _data["purchaseType"] = purchaseType;
    _data["warrantyDuration"] = warrantyDuration;
    _data["serialNumberFormatId"] = serialNumberFormatId;
    _data["label"] = label;
    return _data;
  }

  ProductReference copyWith({
    int? id,
    int? planDuration,
    int? rentDuration,
    int? workDuration,
    int? numberOfItems,
    String? reference,
    String? description,
    String? pictureUrl,
    String? codeReference,
    int? categoryId,
    int? purchaseType,
    int? warrantyDuration,
    int? serialNumberFormatId,
    String? label,
  }) => ProductReference(
    id: id ?? this.id,
    planDuration: planDuration ?? this.planDuration,
    rentDuration: rentDuration ?? this.rentDuration,
    workDuration: workDuration ?? this.workDuration,
    numberOfItems: numberOfItems ?? this.numberOfItems,
    reference: reference ?? this.reference,
    description: description ?? this.description,
    pictureUrl: pictureUrl ?? this.pictureUrl,
    codeReference: codeReference ?? this.codeReference,
    categoryId: categoryId ?? this.categoryId,
    purchaseType: purchaseType ?? this.purchaseType,
    warrantyDuration: warrantyDuration ?? this.warrantyDuration,
    serialNumberFormatId: serialNumberFormatId ?? this.serialNumberFormatId,
    label: label ?? this.label,
  );
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/product_reference.dart <==

class ProductReference {
  int? id;
  int? planDuration;
  int? rentDuration;
  int? workDuration;
  int? numberOfItems;
  String? reference;
  String? description;
  String? pictureUrl;
  String? codeReference;
  int? categoryId;
  int? purchaseType;
  int? warrantyDuration;
  int? serialNumberFormatId;
  String? label;

  ProductReference({this.id, this.planDuration, this.rentDuration, this.workDuration, this.numberOfItems, this.reference, this.description, this.pictureUrl, this.codeReference, this.categoryId, this.purchaseType, this.warrantyDuration, this.serialNumberFormatId, this.label});

  ProductReference.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    planDuration = json["planDuration"];
    rentDuration = json["rentDuration"];
    workDuration = json["workDuration"];
    numberOfItems = json["numberOfItems"];
    reference = json["reference"];
    description = json["description"];
    pictureUrl = json["pictureUrl"];
    codeReference = json["codeReference"];
    categoryId = json["categoryId"];
    purchaseType = json["purchaseType"];
    warrantyDuration = json["warrantyDuration"];
    serialNumberFormatId = json["serialNumberFormatId"];
    label = json["label"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["planDuration"] = planDuration;
    data["rentDuration"] = rentDuration;
    data["workDuration"] = workDuration;
    data["numberOfItems"] = numberOfItems;
    data["reference"] = reference;
    data["description"] = description;
    data["pictureUrl"] = pictureUrl;
    data["codeReference"] = codeReference;
    data["categoryId"] = categoryId;
    data["purchaseType"] = purchaseType;
    data["warrantyDuration"] = warrantyDuration;
    data["serialNumberFormatId"] = serialNumberFormatId;
    data["label"] = label;
    return data;
  }

  ProductReference copyWith({
    int? id,
    int? planDuration,
    int? rentDuration,
    int? workDuration,
    int? numberOfItems,
    String? reference,
    String? description,
    String? pictureUrl,
    String? codeReference,
    int? categoryId,
    int? purchaseType,
    int? warrantyDuration,
    int? serialNumberFormatId,
    String? label,
  }) => ProductReference(
    id: id ?? this.id,
    planDuration: planDuration ?? this.planDuration,
    rentDuration: rentDuration ?? this.rentDuration,
    workDuration: workDuration ?? this.workDuration,
    numberOfItems: numberOfItems ?? this.numberOfItems,
    reference: reference ?? this.reference,
    description: description ?? this.description,
    pictureUrl: pictureUrl ?? this.pictureUrl,
    codeReference: codeReference ?? this.codeReference,
    categoryId: categoryId ?? this.categoryId,
    purchaseType: purchaseType ?? this.purchaseType,
    warrantyDuration: warrantyDuration ?? this.warrantyDuration,
    serialNumberFormatId: serialNumberFormatId ?? this.serialNumberFormatId,
    label: label ?? this.label,
  );
}
